@@ -1,23 +1,18 @@
 package ExtUtils::ModuleMaker;
 use strict;
 use warnings;
-BEGIN {
-    use vars qw( $VERSION @ISA );
-    $VERSION = 0.56;
-    use base qw(
-        ExtUtils::ModuleMaker::Defaults
-        ExtUtils::ModuleMaker::Initializers
-        ExtUtils::ModuleMaker::StandardText
-    );
-};
+our (@ISA);
+our $VERSION = 0.57;
+use base qw(
+    ExtUtils::ModuleMaker::Defaults
+    ExtUtils::ModuleMaker::Initializers
+    ExtUtils::ModuleMaker::StandardText
+);
 use Carp;
-use File::Path;
+use File::Path qw(mkpath);
 use File::Spec;
 use Cwd;
-use File::Save::Home qw(
-    get_subhome_directory_status
-    make_subhome_directory
-);
+use File::HomeDir 0.86;
 
 #################### PUBLICLY CALLABLE METHODS ####################
 
@@ -48,29 +43,50 @@ sub new {
     # _preexists_mmkr_directory and which is then stored in the object.
     # NOTE:  If the directory does not yet exists, it is NOT automatically
     # created.
-    $self->{mmkr_dir_ref} =  get_subhome_directory_status(".modulemaker");
+    if ($supplied_params{debug}) {
+        print "AAA: \@INC: @INC\n";
+        print "AAA: \@ISA: @ISA\n";
+    }
+    $self->{mmkr_dir_ref} =  _get_subhome_directory_status(".modulemaker");
+    if ($supplied_params{debug}) {
+        for my $k (sort keys %{$self->{mmkr_dir_ref}}) {
+            printf("    %-12s%s\n" => $k, $self->{mmkr_dir_ref}->{$k});
+        }
+    }
     {
         my $mmkr_dir = $self->{mmkr_dir_ref}->{abs};
         if (defined $self->{mmkr_dir_ref}->{flag}) {
-            push @INC, $mmkr_dir;
+            print "BBB: mmkr_dir_ref flag: $self->{mmkr_dir_ref}->{flag}\n" if $supplied_params{debug};
+            push @INC, $mmkr_dir unless $INC[-1] eq $mmkr_dir;
+        }
+        else {
+            print "BBB: mmkr_dir_ref flag not found\n" if $supplied_params{debug};
         }
         my $pers_file = File::Spec->catfile( $mmkr_dir,
             qw| ExtUtils ModuleMaker Personal Defaults.pm |
         );
         if (-f $pers_file) {
+            print "CCC: Personal::Defaults module '$pers_file' found\n" if $supplied_params{debug};
             require ExtUtils::ModuleMaker::Personal::Defaults;
-            unshift @ISA, qw(ExtUtils::ModuleMaker::Personal::Defaults);
+            unshift @ISA, qw(ExtUtils::ModuleMaker::Personal::Defaults)
+                unless $ISA[0] eq 'ExtUtils::ModuleMaker::Personal::Defaults';
+        }
+        else {
+            print "CCC: No Personal::Defaults module\n" if $supplied_params{debug};
         }
     }
 
+    print "DDD: \@ISA: @ISA\n" if $supplied_params{debug};
     # 3.  Populate object with default values.  These values will come from
     # lib/ExtUtils/ModuleMaker/Defaults.pm, unless a Personal::Defaults file
     # has been located in step 1 above.
     my $defaults_ref;
     $defaults_ref = $self->default_values();
+    print "EEE: AUTHOR: $defaults_ref->{AUTHOR}\n" if $supplied_params{debug};
     foreach my $param ( keys %{$defaults_ref} ) {
         $self->{$param} = $defaults_ref->{$param};
     }
+    print "FFF: AUTHOR: $self->{AUTHOR}\n" if $supplied_params{debug};
 
 
     # 4.  Process key-value pairs supplied as arguments to new() either
@@ -317,14 +333,13 @@ END_BOTTOMFILE
 
     my $output =  $topfile . $kvpairs . $bottomfile;
 
-    my $mmkr_dir = make_subhome_directory($self->{mmkr_dir_ref});
+    my $mmkr_dir = _make_subhome_directory($self->{mmkr_dir_ref});
     my $full_dir = File::Spec->catdir($mmkr_dir,
         qw| ExtUtils ModuleMaker Personal |
     );
     if (! -d $full_dir) {
-        mkpath( $full_dir );
-        if ($@) {
-            croak "Unable to make directory for placement of personal defaults file: $!"; };
+        mkpath( $full_dir )
+            or croak "Unable to make directory for placement of personal defaults file: $!";
     }
     my $pers_full = File::Spec->catfile( $full_dir, q{Defaults.pm} );
     if (-f $pers_full ) {
@@ -364,6 +379,39 @@ sub _get_dir_and_file {
     return ($dir, $file);
 }
 
+sub _get_subhome_directory_status {
+    my $subdir = shift;
+    my $home = File::HomeDir->my_home;
+    my $dirname = File::Spec->catdir($home, $subdir);
+    my $subdir_top = (File::Spec->splitdir($subdir))[0];
+
+    if (-d $dirname) {
+        return {
+            home    => $home,
+            top     => $subdir_top,
+            abs     => $dirname,
+            flag    => 1,
+       };
+    } else {
+        return {
+            home    => $home,
+            top     => $subdir_top,
+            abs     => $dirname,
+            flag    => undef,
+       };
+    }
+}
+
+sub _make_subhome_directory {
+    my $desired_dir_ref = shift;
+    my $dirname = $desired_dir_ref->{abs};
+    if (! -d $dirname) {
+        mkpath $dirname
+            or croak "Unable to create desired directory $dirname: $!";
+    }
+    return $dirname;
+}
+
 1;
 
 #################### DOCUMENTATION ####################
@@ -404,8 +452,8 @@ Inside a Perl program:
 
 =head1 VERSION
 
-This document references version 0.56 of ExtUtils::ModuleMaker, released
-to CPAN on January 30 2017.
+This document references version 0.57 of ExtUtils::ModuleMaker, released
+to CPAN on May 02 2018.
 
 =head1 DESCRIPTION
 
@@ -566,7 +614,7 @@ is off.)
 
 =item * PERMISSIONS
 
-Used to create new directories.  (Default is 0.56:  group and world can not
+Used to create new directories.  (Default is 0755:  group and world can not
 write.)
 
 =item * USAGE_MESSAGE
@@ -1233,7 +1281,7 @@ C<ExtUtils::ModuleMaker::new()>:
 =item * Tests Require Perl 5.6
 
 While the maintainer has attempted to make the code in
-F<lib/ExtUtils/Modulemaker.pm> and the F<modulemaker> utility compatible
+F<lib/ExtUtils/ModuleMaker.pm> and the F<modulemaker> utility compatible
 with versions of Perl older than 5.6, the test suite currently requires
 5.6 or later.  The tests which require 5.6 or later are placed in SKIP blocks.
 Since the overwhelming majority of the tests I<do> require 5.6, running the
@@ -1308,7 +1356,7 @@ Development repository: L<https://github.com/jkeenan/extutils-modulemaker>
 
 =head1 ACKNOWLEDGMENTS
 
-Thanks first and foremost to Geoff Avery for creating ExtUtils::Modulemaker
+Thanks first and foremost to Geoff Avery for creating ExtUtils::ModuleMaker
 and popularizing it via presentations I attended at YAPC::NA::2003 (Boca
 Raton) and YAPC::EU::2003 (Paris).
 
