@@ -1,9 +1,8 @@
 package ExtUtils::ModuleMaker::Initializers;
-#$Id: Initializers.pm 1153 2007-03-28 00:06:01Z jimk $
 use strict;
-local $^W = 1;
+use warnings;
 use vars qw( $VERSION );
-$VERSION = 0.51;
+$VERSION = 0.57;
 use ExtUtils::ModuleMaker::Licenses::Standard qw(
     Get_Standard_License
     Verify_Standard_License
