@@ -1,11 +1,11 @@
 package ExtUtils::ModuleMaker::Interactive;
-#$Id: Interactive.pm 1153 2007-03-28 00:06:01Z jimk $
+#$Id$
 use strict;
-local $^W = 1;
+use warnings;
 BEGIN {
     use base qw( ExtUtils::ModuleMaker );
     use vars qw ( $VERSION ); 
-    $VERSION = 0.50;
+    $VERSION = 0.57;
 }
 use Carp;
 use Data::Dumper;
@@ -373,7 +373,7 @@ sub Main_Menu {
         }
         elsif ( $response eq 'S' ) {
             my $value =
-              Question_User( "Please enter a 44-character max Abstract for this extension",
+              Question_User( "Please enter Abstract (suggest: 44-char max)",
                 'data' );
             $MOD->{ABSTRACT} = $value;
         }
@@ -630,7 +630,7 @@ James E Keenan.  CPANID:  JKEENAN.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 James E. Keenan.  All rights reserved.
+Copyright (c) 2005, 2018 James E. Keenan.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
