@@ -1,11 +1,11 @@
 package ExtUtils::ModuleMaker::Licenses::Local;
 use strict;
-local $^W = 1;
+use warnings;
 
 BEGIN {
     use base qw(Exporter);
     use vars qw( @EXPORT_OK $VERSION );
-    $VERSION = 0.52;
+    $VERSION = 0.57;
     @EXPORT_OK   = qw(Get_Local_License Verify_Local_License);
 }
 
@@ -78,7 +78,7 @@ ExtUtils::ModuleMaker::Licenses::Local - Templates for the module's License/Copy
 
 =head1 SYNOPSIS
 
-  use ExtUtils::ModuleMaker::Local::Licenses;
+  use ExtUtils::ModuleMaker::Licenses::Local;
   blah blah blah
 
 =head1 DESCRIPTION
@@ -122,7 +122,7 @@ in the subject line.
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2002 R. Geoffrey Avery.
-Revisions from v0.33 forward (c) 2005, 2014 James E. Keenan.  All rights reserved.
+Revisions from v0.33 forward (c) 2005, 2018 James E. Keenan.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
