@@ -1,9 +1,9 @@
 package ExtUtils::ModuleMaker::StandardText;
-#$Id: StandardText.pm 1153 2007-03-28 00:06:01Z jimk $
+#$Id$
 use strict;
-local $^W = 1;
+use warnings;
 use vars qw ( $VERSION );
-$VERSION = 0.50;
+$VERSION = 0.57;
 use ExtUtils::ModuleMaker::Licenses::Standard qw(
     Get_Standard_License
     Verify_Standard_License
@@ -114,11 +114,11 @@ sub print_file {
     $self->log_message( qq{writing file '$filename'});
 
     my $file = File::Spec->catfile( $self->{Base_Dir}, $filename );
-    local *FILE;
-    open( FILE, ">$file" )
-      or $self->death_message( [ qq{Could not write '$filename', $!} ] );
-    print FILE $filetext;
-    close FILE;
+    open my $FILE, '>', $file or
+        $self->death_message( [ qq{Could not write '$filename', $!} ] );
+    print $FILE $filetext;
+    close $FILE or
+        $self->death_message( [ qq{Unable to close after writing, $!} ] );
 }
 
 =head2 Methods Called within C<complete_build()> as an Argument to C<print_file()>
